@@ -76,6 +76,10 @@ def main() -> None:
 
     log = CBCloudLogger('CBRun', package_name)
 
+    # created by run.sh script written in cb_prepare and called here
+    prepare_log_file = ''.join(
+        [args['--root'].rstrip(os.sep), '.prepare.log']
+    )
     # created by run.sh script written in cb_prepare and called here
     build_log_file = ''.join(
         [args['--root'].rstrip(os.sep), '.build.log']
@@ -120,13 +124,14 @@ def main() -> None:
         message='Package build finished',
         response_code=status,
         package=package_name,
+        prepare_log_file=prepare_log_file,
         log_file=build_log_file,
         solver_file=solver_json_file,
         binary_packages=packages,
         exit_code=exit_code
     )
     broker = CBMessageBroker.new(
-        'kafka', config_file=Defaults.get_kafka_config()
+        'kafka', config_file=Defaults.get_broker_config()
     )
     log.response(
         response, broker, build_result_file
