@@ -21,6 +21,7 @@ from typing import NamedTuple
 status_flags = NamedTuple(
     'status_flags', [
         ('package_changed', str),
+        ('package_and_meta_changed', str),
         ('package_build_failed', str),
         ('package_build_succeeded', str),
         ('package_build_running', str),
@@ -154,12 +155,13 @@ class Defaults:
         """
         return status_flags(
             package_changed='package source changed',
+            package_and_meta_changed='package and its metadata changed',
             package_build_failed='package build failed',
             package_build_succeeded='package build succeeded',
             package_build_running='package build running',
             buildroot_setup_failed='build root setup failed',
             buildroot_setup_succeeded='build root setup succeeded',
-            package_update_request='package update request scheduled',
+            package_update_request='fetch service update request scheduled',
             package_request_accepted='package request accepted',
             incompatible_build_arch='incompatible build arch',
             reset_running_build='reset running build',
@@ -181,15 +183,26 @@ class Defaults:
         return f'{os.environ.get("HOME")}/cloud_builder_sources'
 
     @staticmethod
-    def get_kafka_config() -> str:
+    def get_broker_config() -> str:
         """
-        Location of kafka access credentials
+        Location of broker credentials and setup instructions
 
         :return: A file path
 
         :rtype: str
         """
-        return os.path.join(Defaults.__conf_path(), 'kafka.yml')
+        return '/etc/cloud_builder_broker.yml'
+
+    @staticmethod
+    def get_cb_ctl_config() -> str:
+        """
+        Location of control plane (cb-ctl) config file
+
+        :return: A file path
+
+        :rtype: str
+        """
+        return os.path.join(Defaults.__conf_path(), 'cbctl.yml')
 
     @staticmethod
     def __conf_path() -> str:
