@@ -16,8 +16,9 @@
 # along with Cloud Builder.  If not, see <http://www.gnu.org/licenses/>
 #
 import os
-import urllib.request
-from urllib.exceptions import HTTPError
+import uuid
+import requests
+from requests.exceptions import HTTPError
 
 
 class CBIdentity:
@@ -26,14 +27,48 @@ class CBIdentity:
     """
     @staticmethod
     def get_id(service: str, name: str) -> str:
+        """
+        Create identity string.
+
+        The information consists out of the service name,
+        the external host IP if obtainable, the PID of the caller
+        process and some custom name which is usually a package or
+        task name
+
+        :param str service: service name
+        :param str name: custom name
+
+        :return: id string of the format: service:ip:pid:name
+
+        :rtype: str
+        """
         return f'{service}:{CBIdentity.get_external_ip()}:{os.getpid()}:{name}'
 
+    @staticmethod
+    def get_request_id() -> str:
+        """
+        Create a unique UUID, typically for a request to the system
+
+        :return: UUID
+
+        :rtype: str
+        """
+        return format(uuid.uuid1())
+
     @staticmethod
     def get_external_ip() -> str:
+        """
+        Lookup external IP of the system
+
+        Return the IPv4 address or unknown if no public address
+        lookup was possible
+
+        :return: IP address format
+
+        :rtype: str
+        """
         try:
-            return urllib.request.urlopen(
-                'https://api.ipify.org'
-            ).read().decode()
+            return requests.get('https://api.ipify.org').content.decode()
         except HTTPError:
             # if external service IP retrieval failed for some
             # reason continue with an unknown state
